@@ -52,7 +52,7 @@ class OWElectronBeam(GenericElement):
 
         button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal")
 
-        button = gui.button(button_box, self, "Run shadow4/source", callback=self.run_shadow4)
+        button = gui.button(button_box, self, "Run Shadow4/Source", callback=self.run_shadow4)
         button.setStyleSheet("color: darkblue; font-weight: bold; height: 45px;")
 
         button = gui.button(button_box, self, "Reset Fields", callback=self.call_reset_settings)
@@ -214,7 +214,7 @@ class OWElectronBeam(GenericElement):
         moment_xpxp,\
         moment_yy,\
         moment_yyp,\
-        moment_ypyp = electron_beam.get_moments_all()
+        moment_ypyp = electron_beam.get_moments_all(dispersion=False)
 
         self.moment_xx              = round(moment_xx,   16)
         self.moment_xxp             = round(moment_xxp,  16)
@@ -223,7 +223,7 @@ class OWElectronBeam(GenericElement):
         self.moment_yyp             = round(moment_yyp,  16)
         self.moment_ypyp            = round(moment_ypyp, 16)
 
-        x, xp, y, yp                 = electron_beam.get_sigmas_all()
+        x, xp, y, yp                 = electron_beam.get_sigmas_all(dispersion=False)
         ex, ax, bx, ey, ay, by,      = electron_beam.get_twiss_all()
         eta_x, etap_x, eta_y, etap_y = electron_beam.get_dispersion_all()
 
@@ -242,7 +242,7 @@ class OWElectronBeam(GenericElement):
         self.electron_beam_etap_h       = round(etap_x, 8)
         self.electron_beam_etap_v       = round(etap_y, 8)
 
-    def run_shadow4(self): raise NotImplementedError
+    def run_shadow4(self, scanning_data = None): raise NotImplementedError
 
     def _check_dispersion_reset(self):
         proceed = True
