@@ -14,6 +14,7 @@ from oasys2.widget.util.widget_util import EmittingStream
 
 from syned.widget.widget_decorator import WidgetDecorator
 from syned.beamline.element_coordinates import ElementCoordinates
+from syned.beamline.beamline import Beamline
 
 from shadow4.tools.logger import set_verbose
 
@@ -34,8 +35,9 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
         syned_data  = WidgetDecorator.syned_input_data(multi_input=True)
 
     class Outputs:
-        shadow_data = Output("Shadow Data", ShadowData, id="Shadow Data", default=True, auto_summary=False)
+        shadow_data = Output("Shadow Data", ShadowData, default=True, auto_summary=False)
         trigger     = TriggerToolsDecorator.get_trigger_output()
+        syned_data  = Output("Syned Data", Beamline, default=True, auto_summary=False)
 
     #########################################################
     # Position
@@ -51,9 +53,7 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
     oe_orientation_angle_user_value = Setting(0.0)
 
     def __init__(self, show_automatic_box=True, has_footprint=False, show_tab_advanced_settings=True, show_tab_help=False):
-        super().__init__(show_automatic_box=show_automatic_box,
-                         has_footprint=has_footprint,
-                         )
+        super().__init__(show_automatic_box=show_automatic_box, has_footprint=has_footprint)
 
         #
         # main buttons
@@ -64,7 +64,7 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
 
         button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal")
 
-        button = gui.button(button_box, self, "Run shadow4/trace", callback=self.run_shadow4)
+        button = gui.button(button_box, self, "Run Shadow4/Trace", callback=self.run_shadow4)
         button.setStyleSheet("color: darkblue; font-weight: bold; height: 45px;")
 
         button = gui.button(button_box, self, "Reset Fields", callback=self.call_reset_settings)
@@ -108,7 +108,6 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
         if show_tab_advanced_settings:
             self.populate_advanced_setting_subtabs(advanced_setting_subtabs)
 
-
         #########################################################
         # Help
         #########################################################
@@ -123,10 +122,6 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
 
             help_box.layout().addWidget(label)
 
-
-
-
-
         gui.rubber(self.controlArea)
         gui.rubber(self.mainArea)
 
@@ -173,7 +168,6 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
         gui.comboBox(self.orientation_box, self, "oe_orientation_angle", label="O.E. Orientation Angle [deg]",
                      labelWidth=390,
                      items=[0, 90, 180, 270, "Other value..."],
-                     valueType=float,
                      sendSelectedValue=False, orientation="horizontal", callback=self.oe_orientation_angle_user,
                      tooltip="oe_orientation_angle" )
         self.oe_orientation_angle_user_value_le = oasysgui.widgetBox(self.orientation_box, "", addSpace=False,
@@ -285,13 +279,13 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
     def remove_syned_data(self, index):
         pass
 
-    def run_shadow4(self):
+    def run_shadow4(self, scanning_data: ShadowData.ScanningData = None):
         if self.input_data is None:
             self.prompt_exception(ValueError("No input beam"))
             return
+        if not scanning_data: scanning_data = None
 
         try:
-            self.progressBarInit()
             set_verbose()
             self.shadow_output.setText("")
 
@@ -322,28 +316,33 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
             #
             # run
             #
-            self.progressBarInit()
             output_beam, footprint = element.trace_beam()
 
             self._post_trace_operations(output_beam, footprint, element, beamline)
 
             self._set_plot_quality()
+
+            self.progressBarInit()
+
             self._plot_results(output_beam, footprint, progressBarValue=80)
-
             self._plot_additional_results(output_beam, footprint, element, beamline)
 
-            self.progressBarFinished()
-
             #
             # send beam and trigger
             #
-            self.Outputs.shadow_data.send(ShadowData(beam=output_beam, beamline=beamline, footprint=footprint))
+            output_data = ShadowData(beam=output_beam, beamline=beamline, footprint=footprint)
+            output_data.scanning_data = scanning_data
+
+            self.Outputs.shadow_data.send(output_data)
+            self.Outputs.syned_data.send(beamline)
             self.Outputs.trigger.send(TriggerIn(new_object=True))
 
         except Exception as exception:
             try:    self._initialize_tabs()
             except: pass
             self.prompt_exception(exception)
+        finally:
+            self.progressBarFinished()
 
     def _post_trace_operations(self, output_beam, footprint, element, beamline): pass
     def _plot_additional_results(self, output_beam, footprint, element, beamline): pass
