@@ -37,11 +37,11 @@ from orangecontrib.shadow4.widgets.gui.ow_optical_element_with_surface_shape_ren
 class OWOpticalElementWithSurfaceShape(OWOpticalElement):
 
     class Inputs:
-        shadow_data       = OWOpticalElement.Inputs.shadow_data
-        trigger           = OWOpticalElement.Inputs.trigger
-        syned_data        = OWOpticalElement.Inputs.syned_data
-        surface_data      = MultiInput("Oasys Surface Data", OasysSurfaceData, default=True, auto_summary=False)
-        preprocessor_data = MultiInput("Oasys PreProcessor Data", OasysPreProcessorData, default=True, auto_summary=False)
+        shadow_data             = OWOpticalElement.Inputs.shadow_data
+        trigger                 = OWOpticalElement.Inputs.trigger
+        syned_data              = OWOpticalElement.Inputs.syned_data
+        oasys_surface_data      = MultiInput("Oasys Surface Data", OasysSurfaceData, default=True, auto_summary=False)
+        oasys_preprocessor_data = MultiInput("Oasys PreProcessor Data", OasysPreProcessorData, default=True, auto_summary=False)
 
     #########################################################
     # surface shape
@@ -222,7 +222,6 @@ class OWOpticalElementWithSurfaceShape(OWOpticalElement):
             gui.comboBox(box_1, self, "surface_shape_type", label="Figure",
                          labelWidth=390,
                          items=["Plane", "Sphere", "Ellipsoid", "Hyperboloid", "Paraboloid", "Toroid", "Conic coefficients"],
-                         valueType=int,
                          sendSelectedValue=False, orientation="horizontal", callback=self.surface_shape_tab_visibility,
                          tooltip="surface_shape_type")
 
@@ -376,7 +375,6 @@ class OWOpticalElementWithSurfaceShape(OWOpticalElement):
         gui.comboBox(self.cylinder_orientation_box, self, "cylinder_orientation",
                      label="Cylinder Orientation (deg) [CCW from X axis]", labelWidth=350,
                      items=[0, 90],
-                     valueType=float,
                      sendSelectedValue=False, orientation="horizontal", tooltip="cylinder_orientation")
 
         view_shape_box = oasysgui.widgetBox(subtab_surface_shape, "Calculated Surface Shape", addSpace=False, orientation="vertical")
@@ -569,15 +567,15 @@ class OWOpticalElementWithSurfaceShape(OWOpticalElement):
 
         if not is_init: self.__change_icon_from_surface_type()
 
-    @Inputs.preprocessor_data
+    @Inputs.oasys_preprocessor_data
     def set_preprocessor_data(self, index, preprocessor_data):
         self.set_oasys_preprocessor_data(preprocessor_data)
 
-    @Inputs.preprocessor_data.insert
+    @Inputs.oasys_preprocessor_data.insert
     def insert_preprocessor_data(self, index, preprocessor_data):
         self.set_oasys_preprocessor_data(preprocessor_data)
 
-    @Inputs.preprocessor_data.remove
+    @Inputs.oasys_preprocessor_data.remove
     def remove_preprocessor_data(self, index):
         pass
 
@@ -595,15 +593,15 @@ class OWOpticalElementWithSurfaceShape(OWOpticalElement):
                 except Exception as exception:
                     self.prompt_exception(exception)
 
-    @Inputs.surface_data
+    @Inputs.oasys_surface_data
     def set_surface_data(self, index, preprocessor_data):
         self.set_oasys_surface_data(preprocessor_data)
 
-    @Inputs.surface_data.insert
+    @Inputs.oasys_surface_data.insert
     def insert_surface_data(self, index, preprocessor_data):
         self.set_oasys_surface_data(preprocessor_data)
 
-    @Inputs.surface_data.remove
+    @Inputs.oasys_surface_data.remove
     def remove_surface_data(self, index):
         pass
 
@@ -641,19 +639,18 @@ class OWOpticalElementWithSurfaceShape(OWOpticalElement):
             print(">> Current limits: ", self.dim_x_minus, self.dim_x_plus, self.dim_y_minus, self.dim_x_plus)
 
             if (xx.min() > -self.dim_x_minus) or \
-                    (xx.max() > self.dim_x_plus) or \
-                    (yy.min() > -self.dim_y_minus) or \
-                    (yy.max() > self.dim_y_plus):
+               (xx.max() > self.dim_x_plus) or \
+               (yy.min() > -self.dim_y_minus) or \
+               (yy.max() > self.dim_y_plus):
                 if ConfirmDialog.confirmed(parent=self,
                                            message="Dimensions of this O.E. must be changed in order to ensure congruence with the error profile surface, accept?",
-                                           title="Confirm Modification",
-                                           width=600):
+                                           title="Confirm Modification"):
                     self.is_infinite = 0
                     self.oe_shape = 0
-                    self.dim_x_minus = numpy.min((-xx.min(), self.dim_x_minus))
-                    self.dim_x_plus = numpy.min((xx.max(), self.dim_x_plus))
-                    self.dim_y_minus = numpy.min((-yy.min(), self.dim_y_minus))
-                    self.dim_y_plus = numpy.min((yy.max(), self.dim_y_plus))
+                    self.dim_x_minus = -numpy.min((xx.min(), -self.dim_x_minus))
+                    self.dim_x_plus  = numpy.max((xx.max(), self.dim_x_plus))
+                    self.dim_y_minus = -numpy.min((yy.min(), -self.dim_y_minus))
+                    self.dim_y_plus  = numpy.max((yy.max(), self.dim_y_plus))
 
                     print(">> NEW limits: ", self.dim_x_minus, self.dim_x_plus, self.dim_y_minus, self.dim_x_plus)
 
@@ -780,8 +777,8 @@ class ShowSurfaceErrorDataFileDialog(QDialog):
 
         sloperms = profiles_simulation.slopes(zz_slopes, xx, yy, return_only_rms=1)
 
-        title = ' Slope error rms in X: %g $\mu$rad' % (sloperms[0]*1e6) +  \
-                ' in Y: %g $\mu$rad' % (sloperms[1]*1e6) + '\n' + \
+        title = ' Slope error rms in X: %g $\\mu$rad' % (sloperms[0]*1e6) +  \
+                ' in Y: %g $\\mu$rad' % (sloperms[1]*1e6) + '\n' + \
                 ' Figure error rms: %g nm' % (zz.std()*1e9)
 
         axis.set_title(title)
@@ -812,8 +809,8 @@ class ShowImageErrorDataFileDialog(QDialog):
 
         sloperms = profiles_simulation.slopes(zz_slopes, dataX, dataY, return_only_rms=1)
 
-        title = ' Slope error rms in X: %g $\mu$rad' % (sloperms[0]*1e6) +  \
-                ' in Y: %g $\mu$rad' % (sloperms[1]*1e6) + '\n' + \
+        title = ' Slope error rms in X: %g $\\mu$rad' % (sloperms[0]*1e6) +  \
+                ' in Y: %g $\\mu$rad' % (sloperms[1]*1e6) + '\n' + \
                 ' Figure error rms: %g nm' % (data2D.std()*1e9)
         ##################
 
