@@ -27,8 +27,8 @@ class _OWCrystal(OWOpticalElementWithSurfaceShape):
         shadow_data             = OWOpticalElementWithSurfaceShape.Inputs.shadow_data
         trigger                 = OWOpticalElementWithSurfaceShape.Inputs.trigger
         syned_data              = OWOpticalElementWithSurfaceShape.Inputs.syned_data
-        surface_data            = OWOpticalElementWithSurfaceShape.Inputs.surface_data
-        preprocessor_data       = OWOpticalElementWithSurfaceShape.Inputs.preprocessor_data
+        oasys_surface_data      = OWOpticalElementWithSurfaceShape.Inputs.oasys_surface_data
+        oasys_preprocessor_data = OWOpticalElementWithSurfaceShape.Inputs.oasys_preprocessor_data
         bragg_preprocessor_data = Input("VLS-PGM PreProcessor Data", BraggPreProcessorData, default=True, auto_summary=False)
 
 
