@@ -29,8 +29,8 @@ class _OWMultilayer(OWOpticalElementWithSurfaceShape):
         shadow_data              = OWOpticalElementWithSurfaceShape.Inputs.shadow_data
         trigger                  = OWOpticalElementWithSurfaceShape.Inputs.trigger
         syned_data               = OWOpticalElementWithSurfaceShape.Inputs.syned_data
-        surface_data             = OWOpticalElementWithSurfaceShape.Inputs.surface_data
-        preprocessor_data        = OWOpticalElementWithSurfaceShape.Inputs.preprocessor_data
+        oasys_surface_data       = OWOpticalElementWithSurfaceShape.Inputs.oasys_surface_data
+        oasys_preprocessor_data  = OWOpticalElementWithSurfaceShape.Inputs.oasys_preprocessor_data
         mlayer_preprocessor_data = MultiInput("MLayer PreProcessor Data", MLayerPreProcessorData, default=True, auto_summary=False)
 
     reflectivity_source           = Setting(4) # f_refl
